#!/bin/sh

name="sylpheed-claws"
title="Sylpheed Claws"
package="sylpheed-claws"
version="0.9.3"
build="1"
noarch="n"
build_info=""

info="A GTK+ based user-friendly e-mail client."
desc="Sylpheed is a GTK+ based, lightweight, and fast e-mail client.
Almost all commands are accessible with the keyboard. It also has
many features such as multiple accounts, POP3/APOP support, thread
display, and multipart MIME. This is an alternative version of
Sylpheed, called Claws. The main reason for this bleeding edge
branch is to lift some of the burden from the shoulders of Hiroyuki
Yamamoto, Sylpheed's creator. The idea is that Claws regularly
resyncs with Hiroyuki's main branch, and vice-versa."
category="net/client/email"
environment="x11/gtk"
contact="$name@packages.packware.one.pl"
vendor="The Packware Project"
vendor_id="pw"

requires=""
obsoletes=""
conflicts=""

docs_source="ABOUT-NLS,AUTHORS,COPYING,INSTALL,BUGS,NEWS,PATCHES,README,README.claws,TODO,TODO.claws,RELEASE_NOTES.claws"
docs_cwd=""

strip_bin="y"
reset_own="y"
reset_dir="y"
reset_fil="y"
delete_cat="y"

. /usr/src/tgz/lib/builder.defs

add_source http://unc.dl.sourceforge.net/sourceforge/sylpheed-claws/sylpheed-${version}claws.tar.bz2

verbose "Do you want to enable GnuPG support?"
yes_or_no with_gpgme n

if [ "$with_gpgme" = "y" ]; then

    configure_option --enable-gpgme
    build_info "With GnuPG. "
    package_suffix gnupg

fi

verbose "Do you want to enable Clamav plugin?"
yes_or_no with_clamav n

if [ "$with_clamav" = "y" ]; then

    configure_option --enable-clamav-plugin
    build_info "With Clamav. "
    package_suffix clamav

fi

verbose "Do you want to enable MathML viewer plugin?"
yes_or_no with_mathml n

if [ "$with_mathml" = "y" ]; then

    configure_option --enable-mathml-viewer-plugin
    build_info "With MathML. "
    package_suffix mathml

fi

configure_option --prefix=/usr
configure_option --enable-openssl
configure_option --enable-ldap
configure_option --enable-ipv6
configure_option --enable-aspell
configure_option --enable-spamassassin-plugin
configure_option --enable-dillo-viewer-plugin
configure_option --enable-trayicon-plugin

make_option faqdir=/usr/doc/$name-$version/faq
make_option manualdir=/usr/doc/$name-$version/manual

install_option DESTDIR=$pkg_main
install_option faqdir=/usr/doc/$name-$version/faq
install_option manualdir=/usr/doc/$name-$version/manual

parent_package="$package"
write_info main

cd $src1

do_configure
do_make
do_install

rm -f $pkg_main/usr/doc/$name-$version/manual/ja/sylpheed.sgml

make_docs

make_package main

clean_up

# $Log: sylpheed-claws.builder,v $
# Revision 1.28  2003/07/16 09:53:18  swiergot
# - Build 1.
#
# Revision 1.27  2003/07/16 09:40:18  swiergot
# - Version 0.9.3.
#
# Revision 1.26  2003/05/25 18:18:50  swiergot
# - Build 2.
#
# Revision 1.25  2003/05/25 17:52:09  swiergot
# - Rebuild.
#
# Revision 1.24  2003/05/25 10:45:49  swiergot
# - Build 1.
#
# Revision 1.23  2003/05/25 10:09:08  swiergot
# - Ask for MathML viewer plugin build.
#
# Revision 1.22  2003/05/25 09:52:19  swiergot
# - Ask for Clamav plugin build.
#
# Revision 1.21  2003/05/25 09:42:22  swiergot
# - Enable LDAP, IPv6 and Aspell support permamently.
# - GnuPG support is not built by default.
# - Don't use subpackages.
# - Remove all package-* and scheme.* files.
#
# Revision 1.20  2003/05/25 09:23:54  swiergot
# - Don't even ask for SSL support. Just enable it.
# - Enable GnuPG and LDAP support by default.
#
# Revision 1.19  2003/05/25 09:05:09  swiergot
# - Enable Aspell support by default.
#
# Revision 1.18  2003/05/25 08:44:21  swiergot
# - Changed SF mirror to unc.
# - Version 0.9.0claws.
#
# Revision 1.17  2003/03/12 21:52:57  swiergot
# - Build 1.
#
# Revision 1.16  2003/03/12 21:30:23  swiergot
# - Force building.
#
# Revision 1.15  2003/03/12 21:13:23  swiergot
# - Version 0.8.11.
#
# Revision 1.14  2003/02/12 21:18:37  swiergot
# - Build 1.
#
# Revision 1.13  2003/02/12 21:03:32  swiergot
# - Changed server with source from cesnet to osdn.
#
# Revision 1.12  2003/02/12 20:49:59  swiergot
# - Force building.
#
# Revision 1.11  2003/02/12 18:53:16  swiergot
# - Force building.
#
# Revision 1.10  2003/02/12 17:57:17  swiergot
# - Version 0.8.10.
#
# Revision 1.9  2003/02/10 20:33:35  swiergot
# - Build 2.
#
# Revision 1.8  2003/02/10 20:16:08  swiergot
# - Fuck! We broke everything while we was separating the two branches of
#   Sylpheed. Now it should be ok.
#
# Revision 1.7  2003/02/10 19:54:57  swiergot
# - Build 1.
#
# Revision 1.6  2003/02/10 19:39:40  swiergot
# - Added missing claws-specific docs.
# - Added ChangeLog.claws to changelog subpackage.
# - Little cleanups.
#
# Revision 1.5  2003/01/25 14:15:16  swiergot
# - Version 0.8.9claws.
# - Added configure_option --enable-spamassassin-plugin.
#
# Revision 1.4  2003/01/23 19:16:57  swiergot
# - Build 1.
#
# Revision 1.3  2003/01/23 19:03:07  swiergot
# - Corrected OpenSSL configure_option.
#
# Revision 1.2  2003/01/23 18:09:41  swiergot
# - Version 0.8.8.
#
# Revision 1.12  2002/12/26 21:02:28  swiergot
# - Build 2.
#
# Revision 1.11  2002/12/26 20:48:20  swiergot
# - Changed title to "Sylpheed Claws".
#
# Revision 1.10  2002/12/26 20:38:13  swiergot
# - Cleanups in builder.
#
# Revision 1.9  2002/12/26 20:17:51  swiergot
# - Build 1.
#
# Revision 1.8  2002/12/26 19:53:54  swiergot
# - Version 0.8.8claws.
#
# Revision 1.7  2002/12/26 19:38:00  swiergot
# - Build 2.
#
# Revision 1.6  2002/12/26 19:22:45  swiergot
# - Touched to force building.
#
# Revision 1.5  2002/12/26 19:14:51  swiergot
# - Cosmetics.
# - Build 1.
#
# Revision 1.4  2002/12/26 19:03:41  swiergot
# - Downgrade to 0.8.7claws.
#
# Revision 1.3  2002/12/26 18:40:49  swiergot
# - Version 0.8.8claws.
#
# Revision 1.2  2002/12/26 15:14:54  stoodi
# - Build 1.
#
# Revision 1.1  2002/12/26 14:49:15  stoodi
# - Initial release.
# - Version 0.8.7.
#
